@@ -55,6 +55,9 @@ def install(
         "-m",
         help="The mail address used for LetsEncrypt",
     ),
+    environment: str = typer.Option(
+        "development", "--environment", "-e", help="backplane environment"
+    ),
 ):
     error = False
 
@@ -176,7 +179,7 @@ def install(
         if backplane["verbosity"] > 0:
             typer.secho("default config does not exist", err=True, fg=typer.colors.RED)
 
-        if backplane["environment"] == "development":
+        if environment == "development":
             domain = "127-0-0-1.nip.io"
             # try:
             #     subprocess.run(
@@ -384,34 +387,33 @@ def start(
 ):
     backplane_services = services.split(",")
 
-    with typer.progressbar(backplane_services, label="Starting") as progress:
-        for service in progress:
-            docker_compose_command = f"docker-compose -f docker-compose.yml -p backplane-{service} up -d --remove-orphans"
-            project_dir = os.path.join(
-                backplane["active_context_dir"], service, backplane["environment"]
+    for service in backplane_services:
+        docker_compose_command = f"docker-compose -f docker-compose.yml -p backplane-{service} up -d --remove-orphans"
+        project_dir = os.path.join(
+            backplane["active_context_dir"], service, backplane["environment"]
+        )
+
+        if backplane["verbosity"] > 0:
+            typer.secho(
+                f"{docker_compose_command}", err=False, fg=typer.colors.BRIGHT_BLACK
             )
 
+        result = runCommand(docker_compose_command, project_dir)
+        if result.returncode != 0:
+            typer.secho(
+                f"Failed to start {service} in {backplane['active_context_dir']}: {result.stderr}",
+                err=True,
+                fg=typer.colors.RED,
+            )
+            raise typer.Exit(code=result)
+        else:
             if backplane["verbosity"] > 0:
                 typer.secho(
-                    f"{docker_compose_command}", err=False, fg=typer.colors.BRIGHT_BLACK
+                    f"Successfully started {service} in {backplane['active_context_dir']}",
+                    err=False,
+                    fg=typer.colors.GREEN,
                 )
 
-            result = runCommand(docker_compose_command, project_dir)
-            if result.returncode != 0:
-                typer.secho(
-                    f"Failed to start {service} in {backplane['active_context_dir']}: {result.stderr}",
-                    err=True,
-                    fg=typer.colors.RED,
-                )
-                raise typer.Exit(code=result)
-            else:
-                if backplane["verbosity"] > 0:
-                    typer.secho(
-                        f"Successfully started {service} in {backplane['active_context_dir']}",
-                        err=False,
-                        fg=typer.colors.GREEN,
-                    )
-
     status(services)
 
 
@@ -666,26 +668,14 @@ def checkPrerequisites(ctx):
 def callback(
     ctx: typer.Context,
     verbosity: bool = typer.Option(False, "--verbose", "-v", help="Verbose"),
-    environment: str = typer.Option(
-        "development", "--environment", "-e", help="Environment"
-    ),
     version: Optional[bool] = typer.Option(
         None, "--version", callback=version_callback, is_eager=True
     ),
 ):
 
-    backplane["verbosity"] = verbosity
-
     backplane["config_dir"] = os.getenv(
         "BACKPLANE_CONIG_DIR", os.path.join(os.getenv("HOME", "~"), ".backplane")
     )
-
-    load_dotenv(dotenv_path=backplane["config_dir"])
-
-    backplane["environment"] = os.getenv("BACKPLANE_ENVIRONMENT", environment)
-
-    print(backplane["environment"])
-
     backplane["active_context"] = os.getenv("backplane['active_context']", "default")
     backplane["contexts_dir"] = os.getenv(
         "BACKPLANE_CONTEXTS_DIR", os.path.join(backplane["config_dir"], "contexts")
@@ -696,6 +686,13 @@ def callback(
     )
     backplane["active_context_dir"] = backplane["default_context_dir"]
 
+    # Load .env from active context
+    load_dotenv(dotenv_path=f"{backplane['active_context_dir']}/.env")
+
+    backplane["verbosity"] = verbosity
+
+    backplane["environment"] = os.getenv("BACKPLANE_ENVIRONMENT", "development")
+
     checkPrerequisites(ctx)
 
     if backplane["verbosity"] > 0:
